=================
Utility Functions
=================

The ``utils`` module provides helpful functions for `Resample` such as creating image mask from model's DQ array, computing average pixel area, loading a custom WCS from an ASDF file, etc.    

.. currentmodule:: stcal.resample.utils

.. automodapi:: stcal.resample.utils
   :noindex:
